@@ -1,10 +1,10 @@
 from abc import ABC, abstractmethod
 from datetime import datetime
 
-from .constants import SELECT_QUERY, UPDATE_QUERY, INSERT_QUERY, DELETE_QUERY
-from .exceptions import RequiredArgException, ManyPrimaryKeysException, \
+from constants import SELECT_QUERY, UPDATE_QUERY, INSERT_QUERY, DELETE_QUERY, CREATE_QUERY, WHERE_QUERY
+from exceptions import RequiredArgException, ManyPrimaryKeysException, \
     ExtraArgException, NoPrimaryKeysException
-from .loader import conn
+from loader import conn
 
 
 class Model(ABC):
@@ -32,7 +32,7 @@ class Model(ABC):
 
     def _insert_row(self, **kwargs):
         column_names: list[str] = []
-        column_values: list[str] = []
+        column_values = []
         for kwarg_name, kwarg_value in kwargs.items():
             column_names.append(self._class_property_fields[kwarg_name]._name)
             column_values.append(kwarg_value)
@@ -59,6 +59,8 @@ class Model(ABC):
     def __init__(self, **kwargs):
         self._get_class_property_fields()
         self._get_p_key_name_from_fields()
+        self._init_table()
+        self.__class__._p_key_name = self._p_key_name
         for class_property_field in self._class_property_fields.values():
             format_kwargs = dict(name=class_property_field._name,
                                  table=self.table_name, p_key=self._p_key_name)
@@ -68,17 +70,67 @@ class Model(ABC):
         self.save()
         self._get_p_key_value_from_fields()
 
-    def delete(self):
-        delete_query = DELETE_QUERY.format(table=self.table_name,
-                                           p_key=self._p_key_name)
-        conn.execute(delete_query, [self._p_key_value])
+    @classmethod
+    def delete(cls, primary_key_value):
+        delete_query = DELETE_QUERY.format(table=cls.table_name,
+                                           p_key=cls._p_key_name)
+        conn.execute(delete_query, [primary_key_value])
 
     @staticmethod
     def save():
         conn.commit()
 
+    def _init_table(self):
+        values = ''
+        for number, class_property_field in enumerate(self._class_property_fields.values()):
+            if number != 0:
+                values += ',\n'
+            values += class_property_field.name + ' '
+            values += class_property_field.db_name + ' '
+            if class_property_field.is_primary_key:
+                values += 'PRIMARY KEY '
+                if class_property_field._auto_increment:
+                    values += 'AUTOINCREMENT '
+                continue
+            if class_property_field.is_unique:
+                values += 'UNIQUE '
+            if not class_property_field.is_nullable:
+                values += 'NOT NULL '
+        conn.execute(CREATE_QUERY.format(table=self.table_name, values=values))
+
+    @classmethod
+    def get(cls, id):
+        obj = cls.__new__(cls)
+        obj._p_key_value = id
+        obj._get_class_property_fields()
+        obj._get_p_key_name_from_fields()
+        obj._get_p_key_value_from_fields()
+        return obj
+
+    @classmethod
+    def _get_pk_position(cls, **kwargs):
+        filed = cls.__dict__.items()
+        for num, file in enumerate(filed):
+            try:
+                if file[1].is_primary_key:
+                    return num
+            except AttributeError:
+                continue
+        return 0
+
+
+    @classmethod
+    def where(cls, **kwargs):
+        values_list = [f"{key} = '{value}'" for key, value in kwargs.items()]
+        values_str = ' AND '.join(values_list)
+        p_key_value = conn.execute(WHERE_QUERY.format(
+            table=cls.table_name, values=values_str
+        )).fetchone()[cls._get_pk_position()]
+        return cls.get(p_key_value)
+
 
 class Field(ABC):
+    db_name = 'PLACEHOLDER'
     required_max_length = False
     allowed_auto_increment = False
 
@@ -122,17 +174,37 @@ class Field(ABC):
         if instance._p_key_name == self._name:
             instance._p_key_value = value
 
+    @property
+    def is_unique(self):
+        return self._is_unique
+
+    @property
+    def name(self):
+        return self._name
+
+    @property
+    def is_nullable(self):
+        return self._is_nullable
+
+    @property
+    def is_primary_key(self):
+        return self._is_primary_key
+
 
 class StringField(Field):
+    db_name = 'TEXT'
     required_max_length = True
 
 
 class BooleanField(Field):
+    db_name = 'INTEGER'
+
     def __get__(self, instance: Model, owner):
         return bool(super().__get__(instance, owner))
 
 
 class IntegerField(Field):
+    db_name = 'INTEGER'
     allowed_auto_increment = True
 
     def __get__(self, instance: Model, owner):
@@ -140,5 +212,7 @@ class IntegerField(Field):
 
 
 class DateTimeField(Field):
+    db_name = 'INTEGER'
+
     def __get__(self, instance: Model, owner):
         return datetime.fromisoformat(super().__get__(instance, owner))
