@@ -1,10 +1,10 @@
 from datetime import datetime
 
-import .db
+import db
 
 
 class User(db.Model):
-    table_name = 'users'
+    table_name = 'asdfasdf'
     id = db.IntegerField(primary_key=True, auto_increment=True)
     name = db.StringField(max_length=255)
     surname = db.StringField(max_length=255)
@@ -18,6 +18,8 @@ u = User(name='Ruslan', surname='Gazizov', age=18, is_agent_007=True,
 print(f'{u.name=}, {u.surname=}, {u.age=}, {u.birth=}, {u.is_agent_007=}')
 print(type(u.name), type(u.surname), type(u.age), type(u.birth), type(u.is_agent_007))
 
+u = User.where(name='Ruslan', my_age=18)
+
 u.name = 'Другое имя'
 u.surname = 'Другая фамилия'
 u.age = '22'
@@ -26,4 +28,5 @@ u.is_agent_007 = False
 u.save()
 print(f'{u.name=}, {u.surname=}, {u.age=}, {u.birth=}, {u.is_agent_007=}')
 
-u.delete()
+User.delete(primary_key_value=u.id)
+User.save()
